@@ -1,8 +1,7 @@
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
     let resp = nekosbest::get(nekosbest::Category::Nekos).await?;
-    dbg!(&resp);
-    let img_url = resp.url;
+    let img_url = &resp.url;
     println!("{}", img_url);
     Ok(())
 }
