@@ -1,6 +1,6 @@
 use std::ops::{Deref, DerefMut, Index, IndexMut};
 
-use crate::details::NekosDetails;
+use crate::details::Details;
 
 /// A response from the api
 #[derive(serde::Deserialize, Debug, Clone, Hash)]
@@ -45,9 +45,9 @@ impl DerefMut for NekosBestResponse {
 pub struct NekosBestResponseSingle {
     /// The url
     pub url: String,
-    /// The details, in case of [`Category::Nekos`]
-    #[serde(flatten, default)]
-    pub details: Option<NekosDetails>,
+    /// The details
+    #[serde(flatten)]
+    pub details: Details,
 }
 
 impl Deref for NekosBestResponseSingle {
@@ -62,4 +62,4 @@ impl DerefMut for NekosBestResponseSingle {
     fn deref_mut(&mut self) -> &mut Self::Target {
         &mut self.url
     }
-}
\ No newline at end of file
+}
